@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -61,8 +65,8 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 1 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:337  */
 
 /*
  *  Copyright © 2006 Keith Packard <keithp@keithp.com>
@@ -78,13 +82,16 @@ extern void yyerror(yyscan_t, cvs_file *, const char *);
 
 extern YY_DECL;	/* FIXME: once the Bison bug requiring this is fixed */
 
-#line 82 "gram.c" /* yacc.c:339  */
-
+#line 86 "gram.c" /* yacc.c:337  */
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -155,7 +162,7 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 31 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:355  */
+#line 31 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:352  */
 
     int		i;
     cvstime_t	date;
@@ -171,7 +178,7 @@ union YYSTYPE
     cvs_branch	*branch;
     cvs_file	*file;
 
-#line 175 "gram.c" /* yacc.c:355  */
+#line 182 "gram.c" /* yacc.c:352  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -185,9 +192,7 @@ int yyparse (void *scanner, cvs_file *cvsfile);
 
 #endif /* !YY_YY_GRAM_H_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 191 "gram.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -208,13 +213,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -226,7 +231,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -262,15 +267,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -278,7 +274,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -440,16 +436,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  125
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   291
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -688,22 +684,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (scanner, cvsfile, YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (scanner, cvsfile, YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -743,39 +739,39 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, void *scanner, cvs_file *cvsfile)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, void *scanner, cvs_file *cvsfile)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   YYUSE (scanner);
   YYUSE (cvsfile);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, void *scanner, cvs_file *cvsfile)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, void *scanner, cvs_file *cvsfile)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, scanner, cvsfile);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep, scanner, cvsfile);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -809,7 +805,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, void *scanner, cvs_file *cvsfile)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -820,7 +816,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, void *scanner,
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               , scanner, cvsfile);
       YYFPRINTF (stderr, "\n");
     }
@@ -924,7 +920,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -942,7 +941,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1020,10 +1019,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1035,6 +1034,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1046,9 +1046,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1180,23 +1181,31 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1212,14 +1221,10 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1235,22 +1240,22 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1259,11 +1264,11 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1336,7 +1341,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1357,7 +1362,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 88 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 88 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     {
 		    /* The description text (if any) is only used
 		     * for empty log messages in the 'patch' production
@@ -1365,47 +1370,47 @@ yyreduce:
 		     free((void *)cvsfile->description);
 		     cvsfile->description = NULL;
 		  }
-#line 1369 "gram.c" /* yacc.c:1646  */
+#line 1374 "gram.c" /* yacc.c:1652  */
     break;
 
   case 5:
-#line 100 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 100 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { cvsfile->head = atom_cvs_number((yyvsp[-1].number)); }
-#line 1375 "gram.c" /* yacc.c:1646  */
+#line 1380 "gram.c" /* yacc.c:1652  */
     break;
 
   case 6:
-#line 102 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 102 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { cvsfile->branch = atom_cvs_number((yyvsp[-1].number)); }
-#line 1381 "gram.c" /* yacc.c:1646  */
+#line 1386 "gram.c" /* yacc.c:1652  */
     break;
 
   case 7:
-#line 104 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 104 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { warn("ignoring empty branch\n"); }
-#line 1387 "gram.c" /* yacc.c:1646  */
+#line 1392 "gram.c" /* yacc.c:1652  */
     break;
 
   case 9:
-#line 107 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 107 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { cvsfile->symbols = (yyvsp[0].symbol); }
-#line 1393 "gram.c" /* yacc.c:1646  */
+#line 1398 "gram.c" /* yacc.c:1652  */
     break;
 
   case 11:
-#line 110 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 110 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { free((yyvsp[-1].s)); }
-#line 1399 "gram.c" /* yacc.c:1646  */
+#line 1404 "gram.c" /* yacc.c:1652  */
     break;
 
   case 12:
-#line 112 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 112 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { cvsfile->gen.expand = expand_override((yyvsp[-1].s)); }
-#line 1405 "gram.c" /* yacc.c:1646  */
+#line 1410 "gram.c" /* yacc.c:1652  */
     break;
 
   case 18:
-#line 123 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 123 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     {
 		    /********************************************************************
 		     *	From OPTIONS in rcs(1) man page
@@ -1421,99 +1426,99 @@ yyreduce:
 		     *******************************************************************/
 		    (yyval.symbol) = (yyvsp[-1].symbol);
 		  }
-#line 1425 "gram.c" /* yacc.c:1646  */
+#line 1430 "gram.c" /* yacc.c:1652  */
     break;
 
   case 19:
-#line 140 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 140 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.symbol) = NULL;		/* ignore LOGIN */ }
-#line 1431 "gram.c" /* yacc.c:1646  */
+#line 1436 "gram.c" /* yacc.c:1652  */
     break;
 
   case 20:
-#line 142 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 142 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.symbol) = NULL;		/* empty access list */ }
-#line 1437 "gram.c" /* yacc.c:1646  */
+#line 1442 "gram.c" /* yacc.c:1652  */
     break;
 
   case 21:
-#line 145 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 145 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.symbol) = (yyvsp[-1].symbol); }
-#line 1443 "gram.c" /* yacc.c:1646  */
+#line 1448 "gram.c" /* yacc.c:1652  */
     break;
 
   case 22:
-#line 148 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 148 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyvsp[0].symbol)->next = (yyvsp[-1].symbol); (yyval.symbol) = (yyvsp[0].symbol); }
-#line 1449 "gram.c" /* yacc.c:1646  */
+#line 1454 "gram.c" /* yacc.c:1652  */
     break;
 
   case 23:
-#line 150 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 150 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.symbol) = (yyvsp[-1].symbol); }
-#line 1455 "gram.c" /* yacc.c:1646  */
+#line 1460 "gram.c" /* yacc.c:1652  */
     break;
 
   case 24:
-#line 152 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 152 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.symbol) = NULL; }
-#line 1461 "gram.c" /* yacc.c:1646  */
+#line 1466 "gram.c" /* yacc.c:1652  */
     break;
 
   case 25:
-#line 155 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 155 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     {
 		  	(yyval.symbol) = xcalloc (1, sizeof (cvs_symbol), "making symbol");
 			(yyval.symbol)->symbol_name = (yyvsp[-2].atom);
 			(yyval.symbol)->number = atom_cvs_number((yyvsp[0].number));
 		  }
-#line 1471 "gram.c" /* yacc.c:1646  */
+#line 1476 "gram.c" /* yacc.c:1652  */
     break;
 
   case 26:
-#line 162 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 162 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     {
 		        warn("ignoring symbol %s (FreeBSD RELENG_2_1_0 braindamage?)\n", (yyvsp[-2].atom));
 		  }
-#line 1479 "gram.c" /* yacc.c:1646  */
+#line 1484 "gram.c" /* yacc.c:1652  */
     break;
 
   case 28:
-#line 168 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 168 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     {
 		    char    name[CVS_MAX_REV_LEN];
 		    cvs_number_string (&(yyvsp[0].number), name, sizeof(name));
 		    (yyval.atom) = atom (name);
 		  }
-#line 1489 "gram.c" /* yacc.c:1646  */
+#line 1494 "gram.c" /* yacc.c:1652  */
     break;
 
   case 29:
-#line 175 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 175 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { *(yyvsp[-1].vlist) = (yyvsp[0].version); (yyval.vlist) = &(yyvsp[0].version)->next;}
-#line 1495 "gram.c" /* yacc.c:1646  */
+#line 1500 "gram.c" /* yacc.c:1652  */
     break;
 
   case 30:
-#line 177 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 177 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.vlist) = &cvsfile->gen.versions; }
-#line 1501 "gram.c" /* yacc.c:1646  */
+#line 1506 "gram.c" /* yacc.c:1652  */
     break;
 
   case 31:
-#line 181 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 181 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = NULL; }
-#line 1507 "gram.c" /* yacc.c:1646  */
+#line 1512 "gram.c" /* yacc.c:1652  */
     break;
 
   case 32:
-#line 183 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 183 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = (yyvsp[0].atom); }
-#line 1513 "gram.c" /* yacc.c:1646  */
+#line 1518 "gram.c" /* yacc.c:1652  */
     break;
 
   case 42:
-#line 193 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 193 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     {
 		    (yyval.version) = xcalloc (1, sizeof (cvs_version),
 				    "gram.y::revision");
@@ -1540,37 +1545,37 @@ yyreduce:
 		    hash_version(&cvsfile->gen.nodehash, (yyval.version));
 		    ++cvsfile->nversions;			
 		  }
-#line 1544 "gram.c" /* yacc.c:1646  */
+#line 1549 "gram.c" /* yacc.c:1652  */
     break;
 
   case 43:
-#line 221 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 221 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     {
 		    (yyval.date) = lex_date (&(yyvsp[-1].number), scanner, cvsfile);
 		  }
-#line 1552 "gram.c" /* yacc.c:1646  */
+#line 1557 "gram.c" /* yacc.c:1652  */
     break;
 
   case 44:
-#line 226 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 226 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = (yyvsp[-1].atom); }
-#line 1558 "gram.c" /* yacc.c:1646  */
+#line 1563 "gram.c" /* yacc.c:1652  */
     break;
 
   case 45:
-#line 229 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 229 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = (yyvsp[-1].atom); }
-#line 1564 "gram.c" /* yacc.c:1646  */
+#line 1569 "gram.c" /* yacc.c:1652  */
     break;
 
   case 46:
-#line 232 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 232 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.branch) = (yyvsp[-1].branch); }
-#line 1570 "gram.c" /* yacc.c:1646  */
+#line 1575 "gram.c" /* yacc.c:1652  */
     break;
 
   case 47:
-#line 235 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 235 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     {
 			(yyval.branch) = xcalloc (1, sizeof (cvs_branch),
 				    "gram.y::numbers");
@@ -1578,59 +1583,59 @@ yyreduce:
 			(yyval.branch)->number = atom_cvs_number((yyvsp[-1].number));
 			hash_branch(&cvsfile->gen.nodehash, (yyval.branch));
 		  }
-#line 1582 "gram.c" /* yacc.c:1646  */
+#line 1587 "gram.c" /* yacc.c:1652  */
     break;
 
   case 48:
-#line 243 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 243 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.branch) = NULL; }
-#line 1588 "gram.c" /* yacc.c:1646  */
+#line 1593 "gram.c" /* yacc.c:1652  */
     break;
 
   case 49:
-#line 246 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 246 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.number) = (yyvsp[-1].number); }
-#line 1594 "gram.c" /* yacc.c:1646  */
+#line 1599 "gram.c" /* yacc.c:1652  */
     break;
 
   case 50:
-#line 249 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 249 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.number) = (yyvsp[0].number); }
-#line 1600 "gram.c" /* yacc.c:1646  */
+#line 1605 "gram.c" /* yacc.c:1652  */
     break;
 
   case 51:
-#line 251 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 251 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.number).c = 0; }
-#line 1606 "gram.c" /* yacc.c:1646  */
+#line 1611 "gram.c" /* yacc.c:1652  */
     break;
 
   case 52:
-#line 254 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 254 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = (yyvsp[-1].atom); }
-#line 1612 "gram.c" /* yacc.c:1646  */
+#line 1617 "gram.c" /* yacc.c:1652  */
     break;
 
   case 53:
-#line 257 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 257 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { cvsfile->description = (yyvsp[0].s); }
-#line 1618 "gram.c" /* yacc.c:1646  */
+#line 1623 "gram.c" /* yacc.c:1652  */
     break;
 
   case 54:
-#line 260 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 260 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { *(yyvsp[-1].patches) = (yyvsp[0].patch); (yyval.patches) = &(yyvsp[0].patch)->next; }
-#line 1624 "gram.c" /* yacc.c:1646  */
+#line 1629 "gram.c" /* yacc.c:1652  */
     break;
 
   case 55:
-#line 262 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 262 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.patches) = &cvsfile->gen.patches; }
-#line 1630 "gram.c" /* yacc.c:1646  */
+#line 1635 "gram.c" /* yacc.c:1652  */
     break;
 
   case 56:
-#line 265 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 265 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.patch) = xcalloc (1, sizeof (cvs_patch), "gram.y::patch");
 		    (yyval.patch)->number = atom_cvs_number((yyvsp[-2].number));
 		    if (!strcmp((yyvsp[-1].s), "Initial revision\n")) {
@@ -1646,59 +1651,59 @@ yyreduce:
 		    hash_patch(&cvsfile->gen.nodehash, (yyval.patch));
 		    free((yyvsp[-1].s));
 		  }
-#line 1650 "gram.c" /* yacc.c:1646  */
+#line 1655 "gram.c" /* yacc.c:1652  */
     break;
 
   case 57:
-#line 282 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 282 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.s) = (yyvsp[0].s); }
-#line 1656 "gram.c" /* yacc.c:1646  */
+#line 1661 "gram.c" /* yacc.c:1652  */
     break;
 
   case 58:
-#line 285 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 285 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.text) = (yyvsp[0].text); }
-#line 1662 "gram.c" /* yacc.c:1646  */
+#line 1667 "gram.c" /* yacc.c:1652  */
     break;
 
   case 59:
-#line 288 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 288 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = (yyvsp[-1].atom); }
-#line 1668 "gram.c" /* yacc.c:1646  */
+#line 1673 "gram.c" /* yacc.c:1652  */
     break;
 
   case 60:
-#line 291 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 291 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = NULL; }
-#line 1674 "gram.c" /* yacc.c:1646  */
+#line 1679 "gram.c" /* yacc.c:1652  */
     break;
 
   case 63:
-#line 297 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 297 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = NULL; }
-#line 1680 "gram.c" /* yacc.c:1646  */
+#line 1685 "gram.c" /* yacc.c:1652  */
     break;
 
   case 64:
-#line 300 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 300 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = NULL; }
-#line 1686 "gram.c" /* yacc.c:1646  */
+#line 1691 "gram.c" /* yacc.c:1652  */
     break;
 
   case 65:
-#line 303 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 303 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.atom) = NULL; }
-#line 1692 "gram.c" /* yacc.c:1646  */
+#line 1697 "gram.c" /* yacc.c:1652  */
     break;
 
   case 66:
-#line 306 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1646  */
+#line 306 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1652  */
     { (yyval.number) = (yyvsp[-1].number); }
-#line 1698 "gram.c" /* yacc.c:1646  */
+#line 1703 "gram.c" /* yacc.c:1652  */
     break;
 
 
-#line 1702 "gram.c" /* yacc.c:1646  */
+#line 1707 "gram.c" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1723,14 +1728,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -1813,12 +1817,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1880,6 +1882,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1887,6 +1890,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1897,6 +1901,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -1926,13 +1934,13 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 314 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1906  */
+#line 314 "/home/esr/public_html/cvs-fast-export//gram.y" /* yacc.c:1918  */
 
 
 void yyerror(yyscan_t scanner, cvs_file *cvs, const char *msg)
 {
     progress_interrupt();
-    fprintf(stderr, "\"%s\", line %d: cvs-fast-export %s on token %s\n",
+    fprintf(stderr, "%s:%d: cvs-fast-export %s on token %s\n",
 	    cvs->export_name, yyget_lineno(scanner),
 	    msg, yyget_text(scanner));
 }
