@@ -176,7 +176,6 @@ main(int argc, char **argv)
     forest_t        forest;
     export_options_t export_options = {
 	.branch_prefix = "refs/heads/",
-	.id_token_expand =  EXPANDUNSPEC,
     };
     export_stats_t	export_stats;
 
@@ -215,7 +214,6 @@ main(int argc, char **argv)
 	    { "revision-map",       1, 0, 'R' },
 	    { "reposurgeon",        0, 0, 'r' },
             { "graph",              0, 0, 'g' },
-            { "expand",             2, 0, 'k' },
             { "remote",             1, 0, 'e' },
             { "strip",              1, 0, 's' },
             { "progress",           0, 0, 'p' },
@@ -267,9 +265,6 @@ main(int argc, char **argv)
 	case 'P':
 	    import_options.promiscuous = true;
 	    break;
-        case 'k':
-	    export_options.id_token_expand = expand_override(optarg);
-	    break;
 	case 'v':
 	    import_options.verbose++;
 #ifdef YYDEBUG
